==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/el.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Δεν έχει δημιουργηθεί λανθάνουσα μνήμη για όλα τα ημερολόγια",
"Everything seems to be completely cached" => "Όλα έχουν αποθηκευτεί στη cache",
"No calendars found." => "Δε βρέθηκαν ημερολόγια.",
"No events found." => "Δε βρέθηκαν συμβάντα.",
"Wrong calendar" => "Λάθος ημερολόγιο",
"The file contained either no events or all events are already saved in your calendar." => "Το αρχείο που περιέχει είτε κανένα συμβάν είτε όλα τα συμβάντα έχουν ήδη αποθηκευτεί στο ημερολόγιό σας.",
"events has been saved in the new calendar" => "τα συμβάντα αποθηκεύτηκαν σε ένα νέο ημερολόγιο",
"Import failed" => "Η εισαγωγή απέτυχε",
"events has been saved in your calendar" => "το συμβάν αποθηκεύτηκε στο ημερολογιό σου",
"New Timezone:" => "Νέα ζώνη ώρας:",
"Timezone changed" => "Η ζώνη ώρας άλλαξε",
"Invalid request" => "Μη έγκυρο αίτημα",
"Calendar" => "Ημερολόγιο",
"Deletion failed" => "Η διαγραφή απέτυχε",
"ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}",
"user" => "χρήστης",
"group" => "ομάδα",
"Editable" => "Επεξεργάσιμο",
"Shareable" => "Διαμοιράσιμο",
"Deletable" => "Διαγράψιμο",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Birthday" => "Γενέθλια",
"Business" => "Επιχείρηση",
"Call" => "Κλήση",
"Clients" => "Πελάτες",
"Deliverer" => "Προμηθευτής",
"Holidays" => "Διακοπές",
"Ideas" => "Ιδέες",
"Journey" => "Ταξίδι",
"Jubilee" => "Γιορτή",
"Meeting" => "Συνάντηση",
"Other" => "Άλλο",
"Personal" => "Προσωπικό",
"Projects" => "Έργα",
"Questions" => "Ερωτήσεις",
"Work" => "Εργασία",
"by" => "από",
"unnamed" => "ανώνυμο",
"You do not have the permissions to update this calendar." => "Δεν έχετε δικαιώματα για να ενημερώσετε αυτό το ημερολόγιο.",
"You do not have the permissions to delete this calendar." => "Δεν έχετε δικαιώματα να διαγράψετε αυτό το ημερολόγιο.",
"You do not have the permissions to add to this calendar." => "Δεν έχετε δικαιώματα να προσθέσετε σε αυτό το ημερολόγιο.",
"New Calendar" => "Νέα Ημερολόγιο",
"You do not have the permissions to add events to this calendar." => "Δεν έχετε δικαιώματα να προσθέστε συμβάντα σε αυτό το ημερολόγιο.",
"You do not have the permissions to edit this event." => "Δεν έχετε δικαιώματα να επεξεργαστείτε αυτό το συμβάν.",
"You do not have the permissions to delete this event." => "Δεν έχετε δικαιώματα να διαγράψετε αυτό το συμβάν.",
"Does not repeat" => "Μη επαναλαμβανόμενο",
"Daily" => "Καθημερινά",
"Weekly" => "Εβδομαδιαία",
"Every Weekday" => "Κάθε μέρα",
"Bi-Weekly" => "Δύο φορές την εβδομάδα",
"Monthly" => "Μηνιαία",
"Yearly" => "Ετήσια",
"never" => "ποτέ",
"by occurrences" => "κατά συχνότητα πρόσβασης",
"by date" => "κατά ημερομηνία",
"by monthday" => "κατά ημέρα",
"by weekday" => "κατά εβδομάδα",
"Monday" => "Δευτέρα",
"Tuesday" => "Τρίτη",
"Wednesday" => "Τετάρτη",
"Thursday" => "Πέμπτη",
"Friday" => "Παρασκευή",
"Saturday" => "Σάββατο",
"Sunday" => "Κυριακή",
"events week of month" => "συμβάντα της εβδομάδας του μήνα",
"first" => "πρώτο",
"second" => "δεύτερο",
"third" => "τρίτο",
"fourth" => "τέταρτο",
"fifth" => "πέμπτο",
"last" => "τελευταίο",
"January" => "Ιανουάριος",
"February" => "Φεβρουάριος",
"March" => "Μάρτιος",
"April" => "Απρίλιος",
"May" => "Μάϊος",
"June" => "Ιούνιος",
"July" => "Ιούλιος",
"August" => "Αύγουστος",
"September" => "Σεπτέμβριος",
"October" => "Οκτώβριος",
"November" => "Νοέμβριος",
"December" => "Δεκέμβριος",
"by events date" => "κατά ημερομηνία συμβάντων",
"by yearday(s)" => "κατά ημέρα(ες) του έτους",
"by weeknumber(s)" => "κατά εβδομάδα(ες)",
"by day and month" => "κατά ημέρα και μήνα",
"Date" => "Ημερομηνία",
"Cal." => "Ημερ.",
"Sun." => "Κυρ.",
"Mon." => "Δευ.",
"Tue." => "Τρί.",
"Wed." => "Τετ.",
"Thu." => "Πέμ.",
"Fri." => "Παρ.",
"Sat." => "Σάβ.",
"Jan." => "Ιαν.",
"Feb." => "Φεβ.",
"Mar." => "Μάρ.",
"Apr." => "Απρ.",
"May." => "Μαΐ.",
"Jun." => "Ιούν.",
"Jul." => "Ιούλ.",
"Aug." => "Αύγ.",
"Sep." => "Σεπ.",
"Oct." => "Οκτ.",
"Nov." => "Νοέ.",
"Dec." => "Δεκ.",
"All day" => "Ολοήμερο",
"Missing fields" => "Πεδία που λείπουν",
"Title" => "Τίτλος",
"From Date" => "Από Ημερομηνία",
"From Time" => "Από Ώρα",
"To Date" => "Έως Ημερομηνία",
"To Time" => "Έως Ώρα",
"The event ends before it starts" => "Το συμβάν ολοκληρώνεται πριν από την έναρξή του",
"There was a database fail" => "Υπήρξε σφάλμα στη βάση δεδομένων",
"Week" => "Εβδομάδα",
"Month" => "Μήνας",
"List" => "Λίστα",
"Today" => "Σήμερα",
"Calendars" => "Ημερολόγια",
"Settings" => "Ρυθμίσεις",
"Your calendars" => "Τα ημερολόγια σου",
"CalDav Link" => "Σύνδεση CalDAV",
"Share Calendar" => "Διαμοίρασε ένα ημερολόγιο",
"Download" => "Λήψη",
"Edit" => "Επεξεργασία",
"Delete" => "Διαγραφή",
"shared with you by" => "μοιράστηκε μαζί σας από ",
"New calendar" => "Νέο ημερολόγιο",
"Edit calendar" => "Επεξεργασία ημερολογίου",
"Displayname" => "Προβολή ονόματος",
"Active" => "Ενεργό",
"Calendar color" => "Χρώμα ημερολογίου",
"Save" => "Αποθήκευση",
"Submit" => "Υποβολή",
"Cancel" => "Ακύρωση",
"Edit an event" => "Επεξεργασία ενός συμβάντος",
"Export" => "Εξαγωγή",
"Eventinfo" => "Πληροφορίες συμβάντος",
"Repeating" => "Επαναλαμβανόμενο",
"Alarm" => "Ειδοποίηση",
"Attendees" => "Συμμετέχοντες",
"Share" => "Διαμοίρασε",
"Title of the Event" => "Τίτλος συμβάντος",
"Category" => "Κατηγορία",
"Separate categories with commas" => "Διαχώρισε τις κατηγορίες με κόμμα",
"Edit categories" => "Επεξεργασία κατηγοριών",
"All Day Event" => "Ολοήμερο συμβάν",
"From" => "Από",
"To" => "Έως",
"Advanced options" => "Επιλογές για προχωρημένους",
"Location" => "Τοποθεσία",
"Location of the Event" => "Τοποθεσία συμβάντος",
"Description" => "Περιγραφή",
"Description of the Event" => "Περιγραφή του συμβάντος",
"Repeat" => "Επαναλαμβανόμενο",
"Advanced" => "Για προχωρημένους",
"Select weekdays" => "Επιλογή ημερών εβδομάδας",
"Select days" => "Επιλογή ημερών",
"and the events day of year." => "και των ημερών του χρόνου που υπάρχουν συμβάντα.",
"and the events day of month." => "και των ημερών του μήνα που υπάρχουν συμβάντα.",
"Select months" => "Επιλογή μηνών",
"Select weeks" => "Επιλογή εβδομάδων",
"and the events week of year." => "και των εβδομάδων του χρόνου που υπάρουν συμβάντα.",
"Interval" => "Διάστημα",
"End" => "Τέλος",
"occurrences" => "περιστατικά",
"create a new calendar" => "δημιουργία νέου ημερολογίου",
"Import a calendar file" => "Εισαγωγή αρχείου ημερολογίου",
"Please choose a calendar" => "Παρακαλώ επέλεξε ένα ημερολόγιο",
"Name of new calendar" => "Όνομα νέου ημερολογίου",
"Take an available name!" => "Επέλεξε ένα διαθέσιμο όνομα!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Ένα ημερολόγιο με αυτό το όνομα υπάρχει ήδη. Εάν θέλετε να συνεχίσετε, αυτά τα 2 ημερολόγια θα συγχωνευθούν.",
"Import" => "Εισαγωγή",
"Close Dialog" => "Κλείσιμο Διαλόγου",
"Create a new event" => "Δημιουργήστε ένα νέο συμβάν",
"Share with:" => "Διαμοιρασμός με:",
"Shared with" => "Διαμοιράστηκε με",
"Unshare" => "Διακοπή Διαμοιρασμού",
"Nobody" => "Κανείς",
"Shared via calendar" => "Διαμοιράστηκε μέσω ημερολογίου",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "Σημείωση: Οι ενέργειες στα συμβάντα που διαμοιράζονται μέσω ημερολογίου θα επηρεάσουν όλο το ημερολόγιο που διαμοιράζεται.",
"View an event" => "Εμφάνισε ένα συμβάν",
"No categories selected" => "Δεν επελέγησαν  κατηγορίες",
"of" => "του",
"at" => "στο",
"General" => "Γενικά",
"Timezone" => "Ζώνη ώρας",
"Update timezone automatically" => "Αυτόματη ενημέρωση ζώνης ώρας",
"Time format" => "Μορφή ώρας",
"24h" => "24ω",
"12h" => "12ω",
"Start week on" => "Πρώτη μέρα της εβδομάδας",
"Cache" => "Cache",
"Clear cache for repeating events" => "Εκκαθάριση λανθάνουσας μνήμης για επανάληψη συμβάντων",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "Διευθύνσεις συγχρονισμού ημερολογίου CalDAV",
"more info" => "περισσότερες πλροφορίες",
"Primary address (Kontact et al)" => "Κύρια Διεύθυνση(Επαφή και άλλα)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => " iCalendar link(s) μόνο για ανάγνωση"
);

==> owncloud-5.0.9.tgz: owncloud/apps/calendar/l10n/el.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Δεν έχει δημιουργηθεί λανθάνουσα μνήμη για όλα τα ημερολόγια",
"Everything seems to be completely cached" => "Όλα έχουν αποθηκευτεί στη cache",
"No calendars found." => "Δε βρέθηκαν ημερολόγια.",
"No events found." => "Δε βρέθηκαν συμβάντα.",
"Wrong calendar" => "Λάθος ημερολόγιο",
"You do not have the permissions to edit this event." => "Δεν έχετε δικαιώματα να επεξεργαστείτε αυτό το συμβάν.",
"The file contained either no events or all events are already saved in your calendar." => "Το αρχείο που περιέχει είτε κανένα συμβάν είτε όλα τα συμβάντα έχουν ήδη αποθηκευτεί στο ημερολόγιό σας.",
"events has been saved in the new calendar" => "τα συμβάντα αποθηκεύτηκαν σε ένα νέο ημερολόγιο",
"Import failed" => "Η εισαγωγή απέτυχε",
"events has been saved in your calendar" => "το συμβάν αποθηκεύτηκε στο ημερολογιό σου",
"New Timezone:" => "Νέα ζώνη ώρας:",
"Timezone changed" => "Η ζώνη ώρας άλλαξε",
"Invalid request" => "Μη έγκυρο αίτημα",
"Calendar" => "Ημερολόγιο",
"Deletion failed" => "Η διαγραφή απέτυχε",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"user" => "χρήστης",
"group" => "ομάδα",
"Editable" => "Επεξεργάσιμο",
"Shareable" => "Διαμοιράσιμο",
"Deletable" => "Διαγράψιμο",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Κυριακή",
"Monday" => "Δευτέρα",
"Tuesday" => "Τρίτη",
"Wednesday" => "Τετάρτη",
"Thursday" => "Πέμπτη",
"Friday" => "Παρασκευή",
"Saturday" => "Σάββατο",
"Sun." => "Κυρ.",
"Mon." => "Δευ.",
"Tue." => "Τρί.",
"Wed." => "Τετ.",
"Thu." => "Πέμ.",
"Fri." => "Παρ.",
"Sat." => "Σάβ.",
"January" => "Ιανουάριος",
"February" => "Φεβρουάριος",
"March" => "Μάρτιος",
"April" => "Απρίλιος",
"May" => "Μάϊος",
"June" => "Ιούνιος",
"July" => "Ιούλιος",
"August" => "Αύγουστος",
"September" => "Σεπτέμβριος",
"October" => "Οκτώβριος",
"November" => "Νοέμβριος",
"December" => "Δεκέμβριος",
"Jan." => "Ιαν.",
"Feb." => "Φεβ.",
"Mar." => "Μάρ.",
"Apr." => "Απρ.",
"May." => "Μαΐ.",
"Jun." => "Ιούν.",
"Jul." => "Ιούλ.",
"Aug." => "Αύγ.",
"Sep." => "Σεπ.",
"Oct." => "Οκτ.",
"Nov." => "Νοέ.",
"Dec." => "Δεκ.",
"All day" => "Ολοήμερο",
"New Calendar" => "Νέα Ημερολόγιο",
"Missing or invalid fields" => "Κενά ή μη έγκυρα πεδία",
"Title" => "Τίτλος",
"From Date" => "Από Ημερομηνία",
"From Time" => "Από Ώρα",
"To Date" => "Έως Ημερομηνία",
"To Time" => "Έως Ώρα",
"The event ends before it starts" => "Το συμβάν ολοκληρώνεται πριν από την έναρξή του",
"There was a database fail" => "Υπήρξε σφάλμα στη βάση δεδομένων",
"Birthday" => "Γενέθλια",
"Business" => "Επιχείρηση",
"Call" => "Κλήση",
"Clients" => "Πελάτες",
"Deliverer" => "Προμηθευτής",
"Holidays" => "Διακοπές",
"Ideas" => "Ιδέες",
"Journey" => "Ταξίδι",
"Jubilee" => "Γιορτή",
"Meeting" => "Συνάντηση",
"Other" => "Άλλο",
"Personal" => "Προσωπικό",
"Projects" => "Έργα",
"Questions" => "Ερωτήσεις",
"Work" => "Εργασία",
"by" => "από",
"unnamed" => "ανώνυμο",
"You do not have the permissions to update this calendar." => "Δεν έχετε δικαιώματα για να ενημερώσετε αυτό το ημερολόγιο.",
"You do not have the permissions to delete this calendar." => "Δεν έχετε δικαιώματα να διαγράψετε αυτό το ημερολόγιο.",
"You do not have the permissions to add to this calendar." => "Δεν έχετε δικαιώματα να προσθέσετε σε αυτό το ημερολόγιο.",
"You do not have the permissions to add events to this calendar." => "Δεν έχετε δικαιώματα να προσθέστε συμβάντα σε αυτό το ημερολόγιο.",
"You do not have the permissions to delete this event." => "Δεν έχετε δικαιώματα να διαγράψετε αυτό το συμβάν.",
"Busy" => "Απασχολημένος",
"Public" => "Δημόσιο",
"Private" => "Ιδιωτικό",
"Confidential" => "Εμπιστευτικό",
"Does not repeat" => "Μη επαναλαμβανόμενο",
"Daily" => "Καθημερινά",
"Weekly" => "Εβδομαδιαία",
"Every Weekday" => "Κάθε μέρα",
"Bi-Weekly" => "Δύο φορές την εβδομάδα",
"Monthly" => "Μηνιαία",
"Yearly" => "Ετήσια",
"never" => "ποτέ",
"by occurrences" => "κατά συχνότητα πρόσβασης",
"by date" => "κατά ημερομηνία",
"by monthday" => "κατά ημέρα",
"by weekday" => "κατά εβδομάδα",
"events week of month" => "συμβάντα της εβδομάδας του μήνα",
"first" => "πρώτο",
"second" => "δεύτερο",
"third" => "τρίτο",
"fourth" => "τέταρτο",
"fifth" => "πέμπτο",
"last" => "τελευταίο",
"by events date" => "κατά ημερομηνία συμβάντων",
"by yearday(s)" => "κατά ημέρα(ες) του έτους",
"by weeknumber(s)" => "κατά εβδομάδα(ες)",
"by day and month" => "κατά ημέρα και μήνα",
"Date" => "Ημερομηνία",
"Cal." => "Ημερ.",
"Week" => "Εβδομάδα",
"Month" => "Μήνας",
"List" => "Λίστα",
"Today" => "Σήμερα",
"Settings" => "Ρυθμίσεις",
"Your calendars" => "Τα ημερολόγια σου",
"CalDav Link" => "Σύνδεση CalDAV",
"Share Calendar" => "Διαμοίρασε ένα ημερολόγιο",
"Download" => "Λήψη",
"Edit" => "Επεξεργασία",
"Delete" => "Διαγραφή",
"New calendar" => "Νέο ημερολόγιο",
"Edit calendar" => "Επεξεργασία ημερολογίου",
"Displayname" => "Προβολή ονόματος",
"Active" => "Ενεργό",
"Calendar color" => "Χρώμα ημερολογίου",
"Save" => "Αποθήκευση",
"Submit" => "Υποβολή",
"Cancel" => "Ακύρωση",
"Edit an event" => "Επεξεργασία ενός συμβάντος",
"Export" => "Εξαγωγή",
"Eventinfo" => "Πληροφορίες συμβάντος",
"Repeating" => "Επαναλαμβανόμενο",
"Alarm" => "Ειδοποίηση",
"Attendees" => "Συμμετέχοντες",
"Share" => "Διαμοίρασε",
"Title of the Event" => "Τίτλος συμβάντος",
"Category" => "Κατηγορία",
"Separate categories with commas" => "Διαχώρισε τις κατηγορίες με κόμμα",
"Edit categories" => "Επεξεργασία κατηγοριών",
"Access Class" => "Κατηγορία Πρόσβασης",
"All Day Event" => "Ολοήμερο συμβάν",
"From" => "Από",
"To" => "Έως",
"Advanced options" => "Επιλογές για προχωρημένους",
"Location" => "Τοποθεσία",
"Location of the Event" => "Τοποθεσία συμβάντος",
"Description" => "Περιγραφή",
"Description of the Event" => "Περιγραφή του συμβάντος",
"Repeat" => "Επαναλαμβανόμενο",
"Advanced" => "Για προχωρημένους",
"Select weekdays" => "Επιλογή ημερών εβδομάδας",
"Select days" => "Επιλογή ημερών",
"and the events day of year." => "και των ημερών του χρόνου που υπάρχουν συμβάντα.",
"and the events day of month." => "και των ημερών του μήνα που υπάρχουν συμβάντα.",
"Select months" => "Επιλογή μηνών",
"Select weeks" => "Επιλογή εβδομάδων",
"and the events week of year." => "και των εβδομάδων του χρόνου που υπάρουν συμβάντα.",
"Interval" => "Διάστημα",
"End" => "Τέλος",
"occurrences" => "περιστατικά",
"create a new calendar" => "δημιουργία νέου ημερολογίου",
"Import a calendar file" => "Εισαγωγή αρχείου ημερολογίου",
"Please choose a calendar" => "Παρακαλώ επέλεξε ένα ημερολόγιο",
"Name of new calendar" => "Όνομα νέου ημερολογίου",
"Take an available name!" => "Επέλεξε ένα διαθέσιμο όνομα!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Ένα ημερολόγιο με αυτό το όνομα υπάρχει ήδη. Εάν θέλετε να συνεχίσετε, αυτά τα 2 ημερολόγια θα συγχωνευθούν.",
"Remove all events from the selected calendar" => "Αφαίρεση όλων των γεγονότων από το επιλεγμένο ημερολόγιο",
"Import" => "Εισαγωγή",
"Close Dialog" => "Κλείσιμο Διαλόγου",
"Create a new event" => "Δημιουργήστε ένα νέο συμβάν",
"Share with:" => "Διαμοιρασμός με:",
"Shared with" => "Διαμοιράστηκε με",
"Unshare" => "Διακοπή Διαμοιρασμού",
"Nobody" => "Κανείς",
"Shared via calendar" => "Διαμοιράστηκε μέσω ημερολογίου",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "Σημείωση: Οι ενέργειες στα συμβάντα που διαμοιράζονται μέσω ημερολογίου θα επηρεάσουν όλο το ημερολόγιο που διαμοιράζεται.",
"View an event" => "Εμφάνισε ένα συμβάν",
"No categories selected" => "Δεν επελέγησαν  κατηγορίες",
"of" => "του",
"at" => "στο",
"General" => "Γενικά",
"Timezone" => "Ζώνη ώρας",
"Update timezone automatically" => "Αυτόματη ενημέρωση ζώνης ώρας",
"Time format" => "Μορφή ώρας",
"24h" => "24ω",
"12h" => "12ω",
"Start week on" => "Πρώτη μέρα της εβδομάδας",
"Cache" => "Cache",
"Clear cache for repeating events" => "Εκκαθάριση λανθάνουσας μνήμης για επανάληψη συμβάντων",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "Διευθύνσεις συγχρονισμού ημερολογίου CalDAV",
"more info" => "περισσότερες πλροφορίες",
"Primary address (Kontact et al)" => "Κύρια Διεύθυνση(Επαφή και άλλα)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => " iCalendar link(s) μόνο για ανάγνωση"
);
